@@ -4,7 +4,7 @@
 """
 
 
-from .npu import api, predict, compile, train, export
+from .npu import api, predict, compile, train, export, upload_data
 from . import vision, optim, loss
 from .core import DataLoader
 from .version import __version__, _module
@@ -15,3 +15,4 @@ predict.__module__ = _module
 compile.__module__ = _module
 train.__module__ = _module
 export.__module__ = _module
+upload_data.__module__ = _module
