@@ -4,6 +4,6 @@ from .predict import predict
 from .train import train
 from .common import api
 from .Dataset import Dataset
-from .Model import Model, NLPHFModel, nlp_constructor
+from .Model import Model
 from .export import export
 from .DataLoader import DataLoader
