@@ -1,5 +1,3 @@
-import os
-
 import bson
 import requests
 
@@ -46,8 +44,9 @@ def compile(model, input_shape, library, model_label, asynchronous=False):
             print("Saving model locally...")
         file_path = save_model(model, library)
         with open(file_path, "rb") as file:
-            file.seek(0, os.SEEK_END)
-            size = file.tell()
+            size = 0
+            for piece in read_in_chunks(file):
+                size += len(piece)
             if getVerbosity() >= MID_VERBOSITY:
                 print("Model saved locally.")
             print("Model file size is {}. Uploading model now...".format(convert_size(size)))
