@@ -9,10 +9,10 @@ from .web.urls import PREDICT_URL
 
 def predict(model, data, asynchronous=False, callback=None, **kwargs):
     checkModel(model)
-    # if isinstance(model, Task) and model.cache is not None and "model" in model.cache:
-    #     cached_model = model.cache["model"]
-    #     if not isinstance(data, (str, Dataset, dict)):
-    #         validate_model(cached_model, data)
+    if isinstance(model, Task) and model.cache is not None and "model" in model.cache:
+        cached_model = model.cache["model"]
+        if not isinstance(data, (str, Dataset, dict)):
+            validate_model(cached_model, data)
     inference_data = checkData(data)
     task_id = model.task_id if isinstance(model, Task) else ""
     resp = predictApi(model, inference_data, task_id, **kwargs)
@@ -24,7 +24,7 @@ def predict(model, data, asynchronous=False, callback=None, **kwargs):
 
 def predictApi(model, data, task_id, **kwargs):
     data, data_name, start, end = determine_data(data)
-    params = {"token": getToken(), "task_id": task_id, "data_start": start, "data_end": end,
+    params = {"token": getToken(), "task_id": task_id, "start": start, "end": end,
               "data_name": data_name}
     check_model_type(model, params)
     check_data_type(data, "data", params)
