@@ -92,30 +92,29 @@ def hash_model(model, library):
         raise ValueError("Cannot hash... Model type: {} not defined.".format(library))
     return hash.hexdigest()
 
-
 def framework_to_numpy(data):
     try:
         if isinstance(data, np.ndarray):
             return data
-    finally:
+    except:
         pass
     try:
         from torch import Tensor
         if isinstance(data, Tensor):
             return data.numpy()
-    finally:
+    except:
         pass
     try:
         from tensorflow import is_tensor, make_ndarray
         if is_tensor(data):
             return make_ndarray(data)
-    finally:
+    except:
         pass
     try:
         from mxnet import nd
         if isinstance(data, nd.NDArray):
             return data.asnumpy()
-    finally:
+    except:
         pass
     raise ValueError("Could not determine framework data is from. Try pass in numpy array directly.")
 
@@ -139,22 +138,19 @@ def determine_model(model):
             return "pytorch"
     except:
         pass
-    finally:
-        pass
     try:
         from tensorflow.keras import Model
         if isinstance(model, Model):
             return "TF"
     except:
         pass
-    finally:
-        pass
     try:
         from mxnet.gluon.nn import Block
         if isinstance(model, Block):
             return "mxnet"
     except:
         pass
-    finally:
-        pass
+    if isinstance(model, str):
+        if model.endswith(".pt"):
+            return "pytorch"
     raise ValueError("Could not determine framework model is from. Please specify explicitly.")
